@@ -1,7 +1,7 @@
 from __future__ import print_function, division
 
 from pylogconf.core import setup
-from pytconf.config import register_main, get_pytconf
+from pytconf import register_main, config_arg_parse_and_launch
 
 from pyawskit.endpoints.group_default import register_group_default
 
@@ -18,7 +18,7 @@ def main():
     """
     setup()
     register_all_groups()
-    get_pytconf().config_arg_parse_and_launch()
+    config_arg_parse_and_launch()
 
 
 if __name__ == '__main__':
